stac.nonparametric_tests.binomial_sign_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.binomial_sign_test

`stac.nonparametric_tests.` `binomial_sign_test`(*args)

  Performs a binomial sign test for two dependent samples. Tests the hypothesis that the two dependent samples represent two different populations.

  Parameters: | sample1, sample2: array_like The sample measurements for each group.
  Returns: | B-value : float The computed B-value of the test. p-value : float The associated p-value from the B-distribution.

  References

  D.J. Sheskin, Handbook of parametric and nonparametric statistical procedures. crc Press, 2003, Test 19: The Binomial Sign Test for Two Dependent Samples

### Navigation

- index
- STAC Release Candidate documentation »